==> hazelcast-all-3.12.6-sources.jar: com/hazelcast/internal/usercodedeployment/impl/filter/MemberProviderFilterParser.java <==
/*
 * Copyright (c) 2008-2020, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.internal.usercodedeployment.impl.filter;

import com.hazelcast.core.Member;
import com.hazelcast.internal.util.filter.AlwaysApplyFilter;
import com.hazelcast.internal.util.filter.Filter;

public final class MemberProviderFilterParser {

    private static final String HAS_ATTRIBUTE_PREFIX = "HAS_ATTRIBUTE:";

    private MemberProviderFilterParser() {
    }

    public static Filter<Member> parseMemberFilter(String providerFilter) {
        if (providerFilter == null) {
            return AlwaysApplyFilter.newInstance();
        }
        providerFilter = providerFilter.trim();
        if (providerFilter.startsWith(HAS_ATTRIBUTE_PREFIX)) {
            providerFilter = providerFilter.substring(HAS_ATTRIBUTE_PREFIX.length());
            providerFilter = providerFilter.trim();
            return new MemberAttributeFilter(providerFilter);
        } else if (providerFilter.isEmpty()) {
            return AlwaysApplyFilter.newInstance();
        } else {
            throw new IllegalArgumentException("Unknown provider filter: " + providerFilter);
        }
    }
}

==> hazelcast-all-4.1-sources.jar: com/hazelcast/internal/usercodedeployment/impl/filter/MemberProviderFilterParser.java <==
/*
 * Copyright (c) 2008-2020, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.internal.usercodedeployment.impl.filter;

import com.hazelcast.cluster.Member;
import com.hazelcast.internal.util.filter.AlwaysApplyFilter;
import com.hazelcast.internal.util.filter.Filter;

public final class MemberProviderFilterParser {

    private static final String HAS_ATTRIBUTE_PREFIX = "HAS_ATTRIBUTE:";

    private MemberProviderFilterParser() {
    }

    public static Filter<Member> parseMemberFilter(String providerFilter) {
        if (providerFilter == null) {
            return AlwaysApplyFilter.newInstance();
        }
        providerFilter = providerFilter.trim();
        if (providerFilter.startsWith(HAS_ATTRIBUTE_PREFIX)) {
            providerFilter = providerFilter.substring(HAS_ATTRIBUTE_PREFIX.length());
            providerFilter = providerFilter.trim();
            return new MemberAttributeFilter(providerFilter);
        } else if (providerFilter.isEmpty()) {
            return AlwaysApplyFilter.newInstance();
        } else {
            throw new IllegalArgumentException("Unknown provider filter: " + providerFilter);
        }
    }
}
